==> zio-aws-macie2_2.12-5.17.149.1-sources.jar: zio/aws/macie2/model/PutFindingsPublicationConfigurationRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class PutFindingsPublicationConfigurationRequest(
    clientToken: Option[__string] = None,
    securityHubConfiguration: Option[
      zio.aws.macie2.model.SecurityHubConfiguration
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest = {
    import PutFindingsPublicationConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest
      .builder()
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .optionallyWith(
        securityHubConfiguration.map(value => value.buildAwsValue())
      )(_.securityHubConfiguration)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest.ReadOnly =
    zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest
      .wrap(buildAwsValue())
}
object PutFindingsPublicationConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest =
      zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest(
        clientToken.map(value => value),
        securityHubConfiguration.map(value => value.asEditable)
      )
    def clientToken: Option[__string]
    def securityHubConfiguration
        : Option[zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly]
    def getClientToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getSecurityHubConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "securityHubConfiguration",
      securityHubConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest
  ) extends zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest.ReadOnly {
    override val clientToken: Option[__string] =
      scala.Option(impl.clientToken()).map(value => value: __string)
    override val securityHubConfiguration
        : Option[zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly] = scala
      .Option(impl.securityHubConfiguration())
      .map(value => zio.aws.macie2.model.SecurityHubConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest
  ): zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-macie2_2.13-5.17.103.1-sources.jar: zio/aws/macie2/model/PutFindingsPublicationConfigurationRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class PutFindingsPublicationConfigurationRequest(
    clientToken: Option[__string] = None,
    securityHubConfiguration: Option[
      zio.aws.macie2.model.SecurityHubConfiguration
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest = {
    import PutFindingsPublicationConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest
      .builder()
      .optionallyWith(
        clientToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.clientToken)
      .optionallyWith(
        securityHubConfiguration.map(value => value.buildAwsValue())
      )(_.securityHubConfiguration)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest.ReadOnly =
    zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest
      .wrap(buildAwsValue())
}
object PutFindingsPublicationConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest =
      zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest(
        clientToken.map(value => value),
        securityHubConfiguration.map(value => value.asEditable)
      )
    def clientToken: Option[__string]
    def securityHubConfiguration
        : Option[zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly]
    def getClientToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getSecurityHubConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "securityHubConfiguration",
      securityHubConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest
  ) extends zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest.ReadOnly {
    override val clientToken: Option[__string] = scala
      .Option(impl.clientToken())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val securityHubConfiguration
        : Option[zio.aws.macie2.model.SecurityHubConfiguration.ReadOnly] = scala
      .Option(impl.securityHubConfiguration())
      .map(value => zio.aws.macie2.model.SecurityHubConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.PutFindingsPublicationConfigurationRequest
  ): zio.aws.macie2.model.PutFindingsPublicationConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
